dofile("GUI/iup_layout.lua")
dofile("GUI/iup_callbacks.lua")
dofile("GUI/view_config.lua")
dofile("GUI/view_search.lua")
dofile("GUI/view_sector.lua")
dofile("GUI/view_universe.lua")

local refresh_timer = Timer()
function PR.GUI.Refresh()
    -- reset matrix
    PR.GUI.DisplayPanel.sel_row = 0
    PR.GUI.DisplayPanel.delcol = "1--1"
    PR.GUI.DisplayPanel.dellin = "1--1"
    PR.GUI.DisplayPanel.numlin = 1
    PR.GUI.DisplayPanel.numcol = 1
    -- silly workaround to allow the matrix scrollposition to reset
    return refresh_timer:SetTimeout(1, function()
        PR.GUI.DisplayPanel.alignment1 = "ALEFT"
        PR.GUI.DisplayPanel:setcell(1, 1, "No data available")
        PR.GUI.MaxDisplayRows = 1
        PR.GUI.ListedItems = {}

        PR.GUI.Btn_Top1.title = PR.GUI.View
        PR.GUI.Btn_Top1.tooltip = PR.GUI.View .. " view, click for " ..
            PR.GUI.GetNextInArray(PR.GUI.Views, PR.GUI.View) .. " view"
        PR.GUI.Btn_Top2.title = ""
        PR.GUI.Btn_Top2.tooltip = ""
        PR.GUI.Btn_Top2.fgcolor = PR.GUI.Color.Button
        PR.GUI.Btn_Top3.title = ""
        PR.GUI.Btn_Top3.tooltip = ""
        PR.GUI.Btn_Top3.fgcolor = PR.GUI.Color.Button
        PR.GUI.Btn_Top4.title = ""
        PR.GUI.Btn_Top4.tooltip = ""
        PR.GUI.Btn_Top4.fgcolor = PR.GUI.Color.Button
        PR.GUI.UserInput.value = ""
        iup.Detach(PR.GUI.EditBox)
        PR.GUI.Btn_Bottom3.title = ""
        PR.GUI.Btn_Bottom3.tooltip = ""

        if PR.GUI.View == "Sector" then
            PR.GUI.RefreshSectorBox()
            -- for faster checking by PR.TargetScanned to update temps
            PR.GUI.CurrentSectorShowing = PR.GUI.DisplayedSector == PR.LoadedSector
        else
            PR.GUI.CurrentSectorShowing = false
            if PR.GUI.View == "Universe" then
                PR.GUI.RefreshUniverseBox()
            elseif PR.GUI.View == "Search" then
                PR.GUI.RefreshSearchBox()
            elseif PR.GUI.View == "Config" then
                PR.GUI.RefreshConfigBox()
            end
        end
        iup.Refresh(PR.GUI.MainDialog[1][1])
    end)
end

function PR.GUI.ShowGUI()
    if PR.PluginReady then
        -- force a pending update
        PR.SaveNow()
        -- refresh dialog contents, needs to be done before showing it
        PR.GUI.Refresh()

        -- show as either modal popup or regular dialog
        if HUD.visible then
            -- when the HUD is shown, show as a popup to prevent clicking on
            -- the HUD and bringing it to the front
            PR.GUI.MainDialog:popup(iup.CENTER, iup.CENTER)
        else
            -- if the HUD is not shown, we show a regular dialog so the user
            -- can interact with the UI behind
            PR.GUI.MainDialog:showxy(iup.CENTER, iup.CENTER)
        end
    else
        PR.Print("Prospector not ready yet, please wait.")
    end
end

function PR.GUI.Close()
    PR.GUI.MainDialog:hide()
    -- free some memory
    PR.GUI.DisplayPanel.dellin = "1--1"
    PR.GUI.DisplayPanel.delcol = "1--1"
    PR.GUI.ListedItems = {}
    PR.GUI.SectorRoidList = {}
    PR.GUI.SectorOres = {}
    PR.GUI.SystemData = {}
    PR.GUI.ScanTop30Idx = false
    PR.GUI.CurrentSectorShowing = false
    PR.GUI.DisplayedSector = 0
    return iup.CLOSE
end

local fmod = math.fmod
-- returns the next entry in an array, cycling back to the start if the end
-- is reached. returns the first entry if @current_option is not provided
function PR.GUI.GetNextInArray(options, current_option)
    if not current_option and options and next(options) then return options[1] end
    for i, v in ipairs(options) do
        if v == current_option then return options[fmod(i, #options) + 1] end
    end
end

-- helper function to transition DisplayPanel from list to matrix, this
-- allows values to be added as if it was a list as long as this function is
-- run afterwards
function PR.GUI.ListToMatrix()
    PR.GUI.DisplayPanel.numlin = PR.GUI.MaxDisplayRows
    for i = 1, PR.GUI.MaxDisplayRows do
        PR.GUI.DisplayPanel:setcell(i, 1, PR.GUI.DisplayPanel[i] or "")
        PR.GUI.DisplayPanel[i] = nil
    end
end
