function PR.GUI.RefreshSearchBox()
    -- turn PR.Config.Search.Ore into the full ore name
    local function getSearchOreName()
        for i = 1, PR.Ore.n do
            if PR.Ore[i].shortname == PR.Config.Search.Ore then
                return PR.Ore[i].name
            end
        end
        -- just in case we got a bad config value
        PR.Config.Search.Ore = PR.Ore[1].shortname
        return PR.Ore[1].name
    end

    -- load system data, if not yet loaded
    PR.LoadSingleSystemData(PR.GUI.SystemData, PR.Config.Search.System)

    -- get search results
    local systable = PR.GUI.SystemData[PR.Config.Search.System][PR.Config.Search.Ore]
    -- [1] text [2] sectorId [3] note [4] total [5] max [6] within threshold
    local search_results = {}
    local threshold = PR.Config["SearchPercent_" .. PR.Config.Search.Ore]
    if systable ~= nil then
        for sectorId, data in pairs(systable) do
            if data and data[1] ~= 0 then
                local note = ""
                if PR.ConquerableStationSectors[sectorId] then
                    note = PR.Color.Orange .. "  Conquerable Station" ..
                        PR.Color.TERMINATOR
                else
                    note = PR.GUI.GetBotsSighted(sectorId)
                end
                if PR.WormholeLocations[sectorId] then
                    note = note .. PR.Color.Cyan .. "  Wormhole" ..
                        PR.Color.TERMINATOR
                end
                table.insert(search_results, {
                    ShortLocationStr(sectorId), -- 1
                    sectorId, -- 2
                    note, -- 3
                    data[1], -- 4 total count
                    data[2], -- 5 max percentage
                    data[3] or 0, -- 6 count within threshold

                })
            end
        end
    end
    -- sort search results by sector name
    -- we could alternatively sort by asteroid count but this looks nicer
    table.sort(search_results,
        -- sort by column, then row
        --function(a, b) return gkmisc.strnatcasecmp(a[1], b[1]) < 0 end

        --[[
        -- sort by row, then column
        function(a, b)
            local col_a, row_a  = a[1]:match(" ([A-P])-(%d+)")
            local col_b, row_b = b[1]:match(" ([A-P])-(%d+)")
            if row_a < row_b then return true
            elseif row_a > row_b then return false
            else
                if col_a < col_b then return true
                else return false
                end
            end
        end
        ]]

        -- sort by max percentage
        function(a, b) return a[5] > b[5] end
    )

    -- output search results
    PR.GUI.ListedItems = {}
    local result_count = #search_results
    PR.GUI.DisplayPanel.delcol = "1--1"
    PR.GUI.DisplayPanel.numcol = (threshold > 0) and 5 or 4
    PR.GUI.DisplayPanel.numlin = result_count
    PR.GUI.DisplayPanel.alignment1 = "ALEFT"
    PR.GUI.DisplayPanel.alignment2 = "ARIGHT"
    PR.GUI.DisplayPanel.alignment3 = (threshold > 0) and "ARIGHT" or "ALEFT"
    PR.GUI.DisplayPanel.alignment4 = "ALEFT"
    PR.GUI.DisplayPanel.alignment5 = "ALEFT"

    local offset = (threshold > 0) and 1 or 0
    for i = 1, result_count do
        PR.GUI.DisplayPanel:setcell(i, 1, search_results[i][1] .. ":")
        PR.GUI.DisplayPanel:setcell(i, 2, search_results[i][4] .. " total, ")
        if threshold > 0 then
            PR.GUI.DisplayPanel:setcell(i, 3, search_results[i][6] ..
                " at least " .. threshold .. "%, ")
        end
        PR.GUI.DisplayPanel:setcell(i, 3 + offset, "max " ..
            search_results[i][5] .. "%")
        PR.GUI.DisplayPanel:setcell(i, 4 + offset, search_results[i][3])

        PR.GUI.ListedItems[i] = search_results[i][2]
    end
    if result_count == 0 then
        PR.GUI.DisplayPanel:setcell(1, 1, "No known asteroids")
    end
    PR.GUI.MaxDisplayRows = math.max(result_count, 1)

    -- update button titles
    PR.GUI.Btn_Top2.title = getSearchOreName()
    PR.GUI.Btn_Top2.tooltip = "Ore to search for"
    PR.GUI.Btn_Top3.title = PR.Config.Search.Area
    PR.GUI.Btn_Top3.tooltip = "Region to search in"
    PR.GUI.Btn_Top4.title = PR.GUI.SystemData[PR.Config.Search.System].systemname
    PR.GUI.Btn_Top4.tooltip = "System to search in"
end

-- sets PR.Config.Search.System to the next system id in the selected area
function PR.GUI.FetchNextSystem()
    local sysid = PR.Config.Search.System or 0
    local function getId()
        if sysid > 0 then
            for i = 1, PR.Systems.n do
                if PR.Systems[i][1] == sysid then return i end
            end
        end
    end

    local id = getId() or 0
    repeat
        id = id + 1
        if id > PR.Systems.n then id = 1 end
    until PR.SystemOwnership[ PR.Systems[id][1] ] == PR.Config.Search.Area
    PR.Config.Search.System = PR.Systems[id][1]
end

-- returns a colored string indicating what types of bots are sighted -
-- doubles as a station detector via Station Guard bots (except training
-- systems, but we don't care about those since you cannot scan or mine there)
function PR.GUI.GetBotsSighted(sectorId)
    local bots
    -- use my Botwatcher plugin if it's installed
    if PR.Interop.IsBotwatcherInstalled then
        bots = Botwatcher.GetBotsSightedList(sectorId)
    else
        local bots_sighted = GetBotSightedInfoForSector(sectorId)
        if bots_sighted ~= "\n" then
            bots = {}
            for bot in bots_sighted:sub(14):gmatch(" (.-)[,\n]") do
                table.insert(bots, bot)
            end
        end
    end
    if bots then
        for _, bot in ipairs(bots) do
            if bot == "Station Guard" then
                return PR.Color.Green .. "  Station" .. PR.Color.TERMINATOR
            elseif bot ~= "Milanar Guardian" then -- Milanar Guardian is really a collector
                local suffix = bot:sub(-9)
                if suffix ~= "Collector" and suffix ~= "Transport" and
                    suffix ~= " Observer" then
                    return PR.Color.Red .. "  Combat bots" ..
                        PR.Color.TERMINATOR
                end
            end
        end
        return PR.Color.Gold .. "  Collector bots" .. PR.Color.TERMINATOR
    end
    return ""
end
