-- save pending data, stop scanning and reset runtime variables
function PR.FreshStart()
    if PR.GUI.MainDialog.visible == "YES" then
        PR.GUI.Close()
    end
    PR.ScannerOffSwitch()
    PR.SaveNow()
    PR.LastDisplayedRoidId = 0
    PR.MassTarget = 0
    PR.MassTestActive = false
    PR.MassScanCount = 0
    PR.MassScanMax = 0
    PR.LastTemp = 0
    PR.RoidNode = 0
end

-- event handler for SECTOR_CHANGED
function PR.SectorChanged(_, sectorId)
    sectorId = tonumber(sectorId) or GetCurrentSectorid()
    if not sectorId then
        -- this can fail after a ReloadInterface() with bad plugins
        PR.Print(PR.PluginTitle .. " detected a bug with the game, please " ..
            "restart or relog (you are likely about to crash)", true)
        PR.PluginReady = false
        return
    end
    -- first cleanup any left-overs
    PR.FreshStart()
    -- then prepare new sector
    PR.Sector = sectorId
    PR.LoadSector(PR.Sector)
    return PR.StatusPrint()
end

-- save sector and corresponding system summary data
-- set optional differentSectorOnly to true to prevent saving current sector
function PR.SaveNow(differentSectorOnly)
    -- force a pending sector data update
    if PR.SaveSectorId > 0 and
        (not differentSectorOnly or PR.SaveSectorId ~= PR.Sector) then
        PR.SaveSectorNow()
    end
    -- force a pending update of system ore summary data
    if PR.SystemUpdateSectorId > 0 and
        (not differentSectorOnly or PR.SystemUpdateSectorId ~= PR.Sector) then
        return PR.SystemDataUpdateNow()
    end
end

-- save PR.Config
function PR.SaveConfigNow()
    return SaveSystemNotes(spickle(PR.Config), PR.SystemNotesPrefix)
end

-- redirects output to HUD on PC, if HUD is showing, and forceChat is not true
function PR.Print(text, forceChat)
    text = PR.Color.Tomato .. tostring(text) .. PR.Color.TERMINATOR
    if not PR.Config.COLOR then
        text = PR.Color.White .. filter_colorcodes(text) .. PR.Color.TERMINATOR
    end
    if not forceChat and PR.Config.PrintToHUD and HUD.visible then
        return HUD:PrintSecondaryMsg("\t" .. text)
    else
        return print(text)
    end
end

-- returns short ore name for provided full name based on PR.Ore,
-- otherwise full name
function PR.GetOreNameShort(longore)
    for i = 1, PR.Ore.n do
        if PR.Ore[i].name == longore then return PR.Ore[i].shortname end
    end
    return longore
end

-- returns full ore name for provided short name based on PR.Ore,
-- otherwise short name
function PR.GetOreName(shortore)
    for i = 1, PR.Ore.n do
        if PR.Ore[i].shortname == shortore then return PR.Ore[i].name end
    end
    return shortore
end

-- return number of digits of provided integer number
function PR.GetDigitCount(number)
    local digits = 1
    local power_of_10 = 10
    while (power_of_10 <= number) do
        digits = digits + 1
        power_of_10 = power_of_10 * 10
    end
    return digits
end
